@@ -1,5 +1,5 @@
 # -*- encoding: utf-8 -*-
-# kb v0.1.2
+# kb v0.1.3
 # A knowledge base organizer
 # Copyright © 2020, gnc.
 # See /LICENSE for licensing information.
@@ -14,18 +14,19 @@ kb config module
 __all__ = ()
 
 import os
+from sys import platform
 from pathlib import Path
 import toml
 
-
 DEFAULT_CONFIG = {
     "PATH_KB": str(Path(Path.home(), ".kb")),
     "PATH_KB_DB": str(Path(Path.home(), ".kb", "kb.db")),
     "PATH_KB_HIST": str(Path(Path.home(), ".kb", "recent.hist")),
     "PATH_KB_DATA": str(Path(Path.home(), ".kb", "data")),
-    "PATH_KB_CONFIG": str(Path(Path.home(), ".kb", "kb.conf.py")),  # for future use
+    # for future use
+    "PATH_KB_CONFIG": str(Path(Path.home(), ".kb", "kb.conf.py")),
     "PATH_KB_MARKERS": str(Path(Path.home(), ".kb", "markers.toml")),
-    "EDITOR": os.environ.get('EDITOR', 'vim'),
+    "EDITOR": os.environ.get("EDITOR", "vim"),
     "INITIAL_CATEGORIES": ["default",
                            "cheatsheets",
                            "procedures",
